pub trait ComplementWithin<Other: ActiveSet, Parent: ActiveSet>: Sealed + ActiveSet { }Expand description
Proof that Self and Other are complements within a parent set P.
S1 ∪ S2 = P and S1 ∩ S2 = ∅. Used for nested divergence where
merge returns to a parent set rather than All.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.